@@ -95,16 +95,13 @@ class Client:
             return:
                 classified_modality: str - modaity prediction of the document classifier
         '''
-        blob = self.__cloud_storage_wrapper.upload_local_file_to_gcs_bucket(mrn, file_path, "staging_folder", self.client_uuid)
+        blob = self.__cloud_storage_wrapper.upload_file_to_gcs_bucket(mrn, file_path, "staging_folder", self.client_uuid)
         if not blob:
             return blob
 
         gcs_file_path = "gs://"+blob.bucket.name+"/"+blob.name
         classified_modality, classified_file_type = self.__send_request_to_document_classifier(gcs_file_path)
         
-        result = Helpers.delete_blob(blob)
-        if not result:
-            warnings.warn("Error faced when trying to delete blob from staging_folder")
         return classified_modality
         
 
