@@ -80,7 +80,7 @@ class Client:
         if '.bmp' in file_path.lower():
             file_contents = self.__convert_bmp_to_png(file_contents)
             file_path = file_path.replace(file_path[len(file_path) - 3:], 'png')
-
+        
         stripped_mrn        = self.__strip_leading_zeros(mrn)
         hashed_patient_mrn  = Helpers.patient_hash(self.client_uuid, [stripped_mrn])[0]
         hashed_file_name    = Helpers.hash_contents_to_file_name(file_path, file_contents)
@@ -88,6 +88,9 @@ class Client:
         bucket              = self.__google_storage_client.bucket(self.client_uuid)
         blob                = bucket.blob(blob_name)
 
+        if 'pdf' in file_path.lower():
+            blob.content_type = "application/pdf"
+
         if Helpers.try_blob_exists(blob):
             Helpers.print_error("File" + blob.name + " already exists")
             return True
@@ -238,7 +241,8 @@ class Client:
                 contents (string): The files contents
         '''
         try:
-            blob.upload_from_string(contents)
+
+            blob.upload_from_string(contents, content_type=blob.content_type)
             return True
         except Exception as e:
             Helpers.print_error("Could not upload blob " + str(e))
