@@ -135,7 +135,7 @@ class Client:
             Returns:
                 boolean: True if the operation was a success, false if otherwise
         '''
-        now                         = datetime.datetime.now()
+        now                         = datetime.datetime.utcnow()
         patient_data['UPDATED_AT']  = str(now)
         print(patient_data)
         patient_mrn                 = patient_data['MRN']
